@@ -1,13 +1,12 @@
 require 'spec_helper'
 
 describe 'neutron::plugins::ml2::ovn' do
-
   let :pre_condition do
     "class { '::neutron::keystone::authtoken':
       password => 'passw0rd',
      }
      class { 'neutron::server': }
-     class { 'neutron': rabbit_password => 'passw0rd' }"
+     class { 'neutron': }"
   end
 
   let :default_params do
@@ -19,16 +18,11 @@ describe 'neutron::plugins::ml2::ovn' do
        :ovn_l3_mode              => true,
        :vif_type                 => 'ovs',
        :dvr_enabled              => false,
+       :dns_servers              => ['8.8.8.8', '10.10.10.10'],
     }
   end
 
-  let :test_facts do
-    { :operatingsystem           => 'default',
-      :operatingsystemrelease    => 'default'
-    }
-  end
-
-  shared_examples_for 'neutron ovn plugin' do
+  shared_examples 'neutron ovn plugin' do
 
     let :params do
       {}
@@ -39,18 +33,19 @@ describe 'neutron::plugins::ml2::ovn' do
     end
 
     it 'should perform default configuration of' do
-      is_expected.to contain_neutron_plugin_ml2('ovn/ovn_nb_connection').with_value(params[:ovn_nb_connection])
-      is_expected.to contain_neutron_plugin_ml2('ovn/ovn_sb_connection').with_value(params[:ovn_sb_connection])
-      is_expected.to contain_neutron_plugin_ml2('ovn/ovsdb_connection_timeout').with_value(params[:ovsdb_connection_timeout])
-      is_expected.to contain_neutron_plugin_ml2('ovn/neutron_sync_mode').with_value(params[:neutron_sync_mode])
-      is_expected.to contain_neutron_plugin_ml2('ovn/ovn_l3_mode').with_value(params[:ovn_l3_mode])
-      is_expected.to contain_neutron_plugin_ml2('ovn/vif_type').with_value(params[:vif_type])
-      is_expected.to contain_neutron_plugin_ml2('ovn/enable_distributed_floating_ip').with_value(params[:dvr_enabled])
+      should contain_neutron_plugin_ml2('ovn/ovn_nb_connection').with_value(params[:ovn_nb_connection])
+      should contain_neutron_plugin_ml2('ovn/ovn_sb_connection').with_value(params[:ovn_sb_connection])
+      should contain_neutron_plugin_ml2('ovn/ovsdb_connection_timeout').with_value(params[:ovsdb_connection_timeout])
+      should contain_neutron_plugin_ml2('ovn/neutron_sync_mode').with_value(params[:neutron_sync_mode])
+      should contain_neutron_plugin_ml2('ovn/ovn_l3_mode').with_value(params[:ovn_l3_mode])
+      should contain_neutron_plugin_ml2('ovn/vif_type').with_value(params[:vif_type])
+      should contain_neutron_plugin_ml2('ovn/enable_distributed_floating_ip').with_value(params[:dvr_enabled])
+      should contain_neutron_plugin_ml2('ovn/dns_servers').with_value(params[:dns_servers].join(','))
     end
 
   end
 
-  shared_examples_for 'Validating parameters' do
+  shared_examples 'Validating parameters' do
     let :params do
       {}
     end
@@ -62,14 +57,14 @@ describe 'neutron::plugins::ml2::ovn' do
 
     it 'should fail with invalid neutron_sync_mode' do
       params[:neutron_sync_mode] = 'invalid'
-      is_expected.to raise_error(Puppet::Error, /Invalid value for neutron_sync_mode parameter/)
+      should raise_error(Puppet::Error, /Invalid value for neutron_sync_mode parameter/)
     end
 
     it 'should fail with invalid vif_type' do
       params[:vif_type] = 'invalid'
-      is_expected.to raise_error(Puppet::Error, /Invalid value for vif_type parameter/)
+      should raise_error(Puppet::Error, /Invalid value for vif_type parameter/)
       params.delete(:vif_type)
-      is_expected.to contain_neutron_plugin_ml2('ovn/vif_type').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_plugin_ml2('ovn/vif_type').with_value('<SERVICE DEFAULT>')
     end
 
     context 'with DVR' do
@@ -77,7 +72,7 @@ describe 'neutron::plugins::ml2::ovn' do
         params.merge!(:dvr_enabled => true)
       end
       it 'should enable DVR mode' do
-        is_expected.to contain_neutron_plugin_ml2('ovn/enable_distributed_floating_ip').with_value(params[:dvr_enabled])
+        should contain_neutron_plugin_ml2('ovn/enable_distributed_floating_ip').with_value(params[:dvr_enabled])
       end
     end
   end
@@ -90,8 +85,8 @@ describe 'neutron::plugins::ml2::ovn' do
         facts.merge(OSDefaults.get_facts({:processorcount => 8}))
       end
 
-      it_configures 'neutron ovn plugin'
-      it_configures 'Validating parameters'
+      it_behaves_like 'neutron ovn plugin'
+      it_behaves_like 'Validating parameters'
     end
   end
 end
